@@ -67,7 +67,7 @@ class TestEuropeanCallExpectedValue(QiskitFinanceTestCase):
                 Aer,
             )  # pylint: disable=unused-import,import-outside-toplevel
         except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest("Aer doesn't appear to be installed. Error: '{}'".format(str(ex)))
+            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
             return
 
         bounds = np.array([0.0, 7.0])
@@ -113,7 +113,7 @@ class TestEuropeanCallExpectedValue(QiskitFinanceTestCase):
         )
         iae = IterativeAmplitudeEstimation(epsilon_target=0.01, alpha=0.05, quantum_instance=q_i)
         result = iae.estimate(problem)
-        self.assertAlmostEqual(result.estimation_processed, 1.0127253837345427)
+        self.assertAlmostEqual(result.estimation_processed, 1.0364776997977694)
 
 
 if __name__ == "__main__":
